@@ -313,7 +313,7 @@ read_config(char *file, struct cfentry *cfe, int count, void *data)
                 case CF_INTEGER:
                 case CF_INT_PLUS:
                     {
-                        unsigned int value;
+                        size_t value;
                         char   *tmp;
 
                         if (*str == '\0') {
