@@ -1007,8 +1007,8 @@ encode_mime(char *str, int len)
     char   *ip;
     char   *op;
     struct strset ss;
-    int     ileft;
-    int     oleft;
+    size_t     ileft;
+    size_t     oleft;
     int     ret;
     iconv_t icd;
     int     error;
@@ -1016,8 +1016,8 @@ encode_mime(char *str, int len)
     /* ñ̤ʬ䤹뤿֥Хåե */
     char    str_divide[ENC_STR_DIVIDE_LEN + 2];
     char   *str_divide_tmp;
-    int     str_divide_len;
-    int     str_divide_len_tmp;
+    size_t     str_divide_len;
+    size_t     str_divide_len_tmp;
     int     b64_enc_size;
 
     strset_init(&ss);
