@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: mailzip.c,v $
- * $Revision: 1.16 $
- * $Date: 2010/04/10 03:00:55 $
+ * $Revision: 1.19 $
+ * $Date: 2010/09/27 07:33:44 $
  */
 
 #include <stdio.h>
@@ -45,13 +45,11 @@
 #include "maildrop.h"
 #include "mailsave.h"
 #include "zipconv.h"
-#include "global.h"
 #include "samma_policy.h"
+#include "global.h"
 
 #define MLFIPRIV(ctx)        ((struct mlfiPriv *) smfi_getpriv(ctx))
 
-extern pthread_mutex_t gmime_lock;
-
 /*
  *  sfsistat mlfi_connect
  */
@@ -127,6 +125,7 @@ mlfi_envfrom(SMFICTX *ctx, char **envfrom)
     char *fromaddr;
     int ret;
     struct mlfiPriv *priv;
+    char *fqdn;
 
     if ((priv = MLFIPRIV(ctx)) == NULL) {
 	log(ERR_GET_PRIV, "mlfi_envfrom");
@@ -144,6 +143,14 @@ mlfi_envfrom(SMFICTX *ctx, char **envfrom)
         return SMFIS_TEMPFAIL;
     }
 
+    /* domain null check */
+    fqdn = strchr(fromaddr, ATMARK);
+    if (fqdn == NULL) {
+        free(fromaddr);
+        mlfi_cleanup(ctx, MLFIABORT);
+        return SMFIS_ACCEPT;
+    }
+
     /* search fromaddr */
     ret = search_fromaddr_bdb(priv->mlfi_conf, fromaddr);
     if (ret < 0) {
@@ -227,8 +234,8 @@ mlfi_header(SMFICTX *ctx, char *headerf, char *headerv)
 
     /* RcptTo Check */
     if (priv->mlfi_rcptcheck == BEFOR_RCPTCHECK) {
-	ret = search_rcptaddr_bdb(priv->mlfi_conf, priv->mlfi_savercpt, &passlist,
-                              &rdmpasslist);
+	ret = search_rcptaddr(priv->mlfi_conf, priv->mlfi_savefrom, 
+			      priv->mlfi_savercpt, &passlist, &rdmpasslist);
 	if (ret < 0) {
 	    free_rcptinfo(passlist);
 	    free_rcptinfo(rdmpasslist);
@@ -560,9 +567,7 @@ main(int argc, char *argv[])
     }
 
     /* initialize GMime */
-    pthread_mutex_lock(&gmime_lock);
     g_mime_init (GMIME_ENABLE_RFC2047_WORKAROUNDS);
-    pthread_mutex_unlock(&gmime_lock);
 
     /* prepare socket string */
     sprintf(oconn, OCONN, cfg->cf_listenport, cfg->cf_listenip);
@@ -577,9 +582,7 @@ main(int argc, char *argv[])
     if(smfi_setconn(oconn) == MI_FAILURE) {
         fprintf(stderr, ERR_MILTER_SET_SOCKET, strerror(errno));
 	fprintf(stderr, "\n");
-	pthread_mutex_lock(&gmime_lock);
 	g_mime_shutdown();
-	pthread_mutex_unlock(&gmime_lock);
         exit(3);
     }
 
@@ -587,9 +590,7 @@ main(int argc, char *argv[])
     if(smfi_settimeout(timeout) == MI_FAILURE) {
         fprintf(stderr, ERR_MILTER_SET_TIMEOUT, strerror(errno));
 	fprintf(stderr, "\n");
-	pthread_mutex_lock(&gmime_lock);
 	g_mime_shutdown();
-	pthread_mutex_unlock(&gmime_lock);
         exit(3);
     }
 
@@ -597,9 +598,7 @@ main(int argc, char *argv[])
     if(smfi_register(smfilter) == MI_FAILURE) {
         fprintf(stderr, ERR_MILTER_REGISTER, strerror(errno));
 	fprintf(stderr, "\n");
-	pthread_mutex_lock(&gmime_lock);
 	g_mime_shutdown();
-	pthread_mutex_unlock(&gmime_lock);
         exit(4);
     }
 
@@ -607,14 +606,11 @@ main(int argc, char *argv[])
     if(smfi_main() == MI_FAILURE) {
         fprintf(stderr, ERR_MILTER_START, strerror(errno));
 	fprintf(stderr, "\n");
-	pthread_mutex_lock(&gmime_lock);
 	g_mime_shutdown();
-	pthread_mutex_unlock(&gmime_lock);
         exit(5);
     }
 
-    pthread_mutex_lock(&gmime_lock);
     g_mime_shutdown();
-    pthread_mutex_unlock(&gmime_lock);
+
     exit(0);
 }
