@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: zipconv.c,v $
- * $Revision: 1.15 $
- * $Date: 2010/04/10 03:01:49 $
+ * $Revision: 1.19 $
+ * $Date: 2010/11/05 06:20:17 $
  */
 
 #include <stdio.h>
@@ -39,7 +39,6 @@
 #include <libdgstr.h>
 
 #include "mailzip_config.h"
-#include "mailzip_tmpl.h"
 #include "mailsave.h"
 #include "zipconv.h"
 #include "log.h"
@@ -47,6 +46,7 @@
 #include "maildrop.h"
 #include "sendmail.h"
 #include "global.h"
+#include "mailzip_tmpl.h"
 
 static void zip_child(char **, char *, char *, char *);
 pthread_mutex_t gmime_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -275,6 +275,12 @@ add_attach_file(struct mailzip *mz, struct rcptinfo *rcpt)
 
         for (i = index - 1; i > 0; i--) {
             att = g_mime_multipart_get_part((GMimeMultipart *)object, i);
+	    if (GMIME_IS_MULTIPART (att)) {
+                g_object_unref (att);
+                att = NULL;
+                continue;
+	    }
+
             filename = g_mime_part_get_filename((GMimePart *)att);
             if (filename == NULL) {
                 g_object_unref (att);
@@ -618,7 +624,8 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 
     ct_object = g_mime_object_get_content_type(object);
     if ((strncmp(ct_object->type, CONTENT_T_MULTIPART, LEN_CONTENT_T_MULTIPART) == 0) && 
-	(strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0)) {
+        ((strncmp(ct_object->subtype, CONTENT_SUBT_RELATED, LEN_CONTENT_SUBT_RELATED) == 0) ||
+         (strncmp(ct_object->subtype, CONTENT_SUBT_ALTERNATIVE, LEN_CONTENT_SUBT_ALTERNATIVE) == 0))) {
         g_object_unref (object);
 	pthread_mutex_unlock(&gmime_lock);
 	return(PM_NO_ATTACHFILE);
@@ -728,7 +735,7 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
         }
 	
 	/* convert str code */
-	if (dg_str2code(tmpname, &tmpfilename, "UTF8", cfg->cf_strcode) != 0) {
+	if (dg_str2code(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
 	    log(ERR_CHARCODE_CONVERT, "drop_file");
             g_object_unref (att);
 	    free(tmpname);
@@ -940,7 +947,7 @@ mk_encpath(struct config *cfg, struct mailzip *mz)
     ti = localtime(&now);
 
     /* allocate date string */
-    strdatenum = strlen(cfg->cf_zipfilename) + STRYEARNUM + STRMONTHNUM + STRDATENUM + 1;
+    strdatenum = strlen(cfg->cf_zipfilename) + STRTIMENUM + 1;
     filename = malloc(strdatenum);
     if (filename == NULL) {
 	log(ERR_MEMORY_ALLOCATE, "add_enclist", "rcptinfo", strerror(errno));
