@@ -20,8 +20,8 @@
 
 /*
  * $RCSfile: zipconv.h,v $
- * $Revision: 1.9 $
- * $Date: 2010/04/10 03:02:07 $
+ * $Revision: 1.11 $
+ * $Date: 2010/11/05 06:20:12 $
  */
 #include <libmilter/mfapi.h>
 #include "mailzip_config.h"
@@ -30,9 +30,7 @@
 #ifndef _MAILZIP_ZIPCONV_H_
 #define _MAILZIP_ZIPCONV_H_
 
-#define STRYEARNUM      4
-#define STRMONTHNUM     2
-#define STRDATENUM      2
+#define STRTIMENUM	128
 #define OPTIONRP        "-rP"
 #define OPTIONRPLEN     sizeof(OPTIONRP)
 #define OPTIONEND "--"
@@ -133,5 +131,7 @@ void free_rcptinfo(struct rcptinfo *);
 #define LEN_CONTENT_T_MULTIPART		sizeof(CONTENT_T_MULTIPART)
 #define CONTENT_SUBT_RELATED		"related"
 #define LEN_CONTENT_SUBT_RELATED	sizeof(CONTENT_SUBT_RELATED)
+#define CONTENT_SUBT_ALTERNATIVE        "alternative"
+#define LEN_CONTENT_SUBT_ALTERNATIVE    sizeof(CONTENT_SUBT_ALTERNATIVE)
 
 #endif /* _MAILZIP_ZIPCONV_H_ */
